Quaternion

Struct Quaternion 

pub struct Quaternion {
    pub w: f32,
    pub x: f32,
    pub y: f32,
    pub z: f32,
}
A quaternion using Hamilton (not JPL) transformation conventions. The most common operations usedful for representing orientations and rotations are defined, including for operations with Vec3.

Fields

w: f32x: f32y: f32z: f32

Implementations

Source

impl Quaternion

pub const fn new_identity() -> Self

pub fn new(w: f32, x: f32, y: f32, z: f32) -> Self

pub fn from_slice(slice: &[f32]) -> Result<Self, BufError>

Construct from the first 4 values in a slice: &[w, x, y, z].

pub fn to_arr(&self) -> [f32; 4]

Convert to a len-4 array: [w, x, y, z].

pub fn from_axis_angle(axis: Vec3, angle: f32) -> Self

Create a rotation quaternion from an axis and angle.

pub fn from_unit_vecs(v0: Vec3, v1: Vec3) -> Self

Create the quaternion that creates the shortest (great circle) rotation from vec0 to vec1.

pub fn from_euler(euler: &EulerAngle) -> Self

Convert Euler angles to a quaternion. https://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles

pub fn to_euler(&self) -> EulerAngle

Convert this quaternion to Tait-Bryon (Euler) angles. We use this reference: http://marc-b-reynolds.github.io/math/2017/04/18/TaitEuler.html. Most sources online provide us with results that do not behave how we expect.

pub fn axis(&self) -> Vec3

Extract the axis of rotation.

pub fn angle(&self) -> f32

Extract the axis of rotation.

pub fn to_axes(&self) -> (f32, f32, f32)

Convert an attitude to rotations around individual axes. Assumes X is left, Z is Z_VEC, and Y is Y_VEC.

pub fn to_vec(self) -> Vec3

Convert to a 3D vector, discarding w.

pub fn slerp(&self, end: Quaternion, amount: f32) -> Quaternion

Performs Spherical Linear Interpolation between this and another quaternion. A high amount will make the result more towards end. An amount of 0 will result in this quaternion. Ref: https://github.com/bitshifter/glam-rs/blob/main/src/$f/scalar/quat.rs#L567 Alternative implementation to examine: https://github.com/MartinWeigel/Quaternion/blob/master/Quaternion.c

pub fn to_matrix(&self) -> Mat4

Converts a Quaternion to a rotation matrix

pub fn to_matrix3(&self) -> Mat3

Converts a Quaternion to a rotation matrix

Source

impl Quaternion

pub fn magnitude(&self) -> f32

Returns the magnitude.

pub fn normalize(&mut self)

Normalize, modifying in place.

pub fn to_normalized(self) -> Self

Returns the normalized version of the vector.

pub fn dot(&self, rhs: Self) -> f32

Used by slerp.

pub fn inverse(self) -> Self

pub fn rotate_vec(self, vec: Vec3) -> Vec3

Rotate a vector using this quaternion. Note that our multiplication Q * v operation is effectively quaternion multiplication, with a quaternion created by a vec with w=0. Uses the X_VEC hand rule.