Vec4x16

Struct Vec4x16 

pub struct Vec4x16 {
    pub x: f32x16,
    pub y: f32x16,
    pub z: f32x16,
    pub w: f32x16,
}
SoA. Performs operations on x Vecs.

Fields

x: f32x16y: f32x16z: f32x16w: f32x16

Implementations

Source

impl Vec4x16

pub fn hadamard_product(self, rhs: Self) -> Self

Calculates the Hadamard product (element-wise multiplication).

pub fn magnitude_squared(self) -> f32x16

Returns the vector magnitude squared

pub fn magnitude(&self) -> f32x16

Returns the vector magnitude

pub fn normalize(&mut self)

Normalize, modifying in place.

pub fn to_normalized(self) -> Self

Returns the normalized version of the vector.

pub fn dot(&self, rhs: Self) -> f32x16

Returns the dot product with another vector.

pub fn project_to_plane(self, plane_norm: Self) -> Self

Project a vector onto a plane defined by its normal vector. Assumes self and plane_norm are unit vectors.

pub fn project_to_vec(self, other: Self) -> Self

Projects this vector onto another vector.

Source

impl Vec4x16

pub fn from_array(arr: [Vec4; 16]) -> Self

pub fn from_slice(slice: &[Vec4]) -> Self

pub fn to_array(self) -> [Vec4; 16]

Convert the SoA data back into an array of eight Vec3s.

pub fn new_zero() -> Self

pub fn splat(val: Vec4) -> Self