Quaternionx8

Struct Quaternionx8 

pub struct Quaternionx8 {
    pub w: f64x8,
    pub x: f64x8,
    pub y: f64x8,
    pub z: f64x8,
}
SoA. Performs operations on x quaternions

Fields

w: f64x8x: f64x8y: f64x8z: f64x8

Implementations

Source

impl Quaternionx8

pub fn magnitude(&self) -> f64x8

Returns the magnitude.

pub fn normalize(&mut self)

Normalize, modifying in place.

pub fn to_normalized(self) -> Self

Returns the normalized version of the vector.

pub fn dot(&self, rhs: Self) -> f64x8

Used by slerp.

pub fn inverse(self) -> Self

pub fn rotate_vec(self, vec: Vec3x8) -> Vec3x8

Rotate a vector using this quaternion. Note that our multiplication Q * v operation is effectively quaternion multiplication, with a quaternion created by a vec with w=0. Uses the X_VEC hand rule.

Source

impl Quaternionx8

pub fn from_array(slots: [Quaternion; 8]) -> Self

Create a new x-lane, SoA, $f Vec3

pub fn from_slice(slice: &[Quaternion]) -> Self

pub fn to_array(self) -> [Quaternion; 8]

Convert the SoA data back into an array of eight Quaternions.

pub fn new_identity() -> Self

pub fn splat(val: Quaternion) -> Self

pub fn to_vec(self) -> Vec3x8

Converts the SIMD quaternion to a SIMD 3D vector, discarding w.