A quaternion using Hamilton (not JPL) transformation conventions. The most common operations
usedful for representing orientations and rotations are defined, including for operations
with Vec3.
Calculate the dihedral angle between 4 positions (3 bonds). Compared to calc_dihedral_angle_v2(),
this function’s API is more clear if you have the bonds/connections, but not the positions.
this might happen if you are doing certain vector operations, for example.
Calculate the dihedral angle between 4 positions. The positions must be in order by
connection/bond, although both directions produce identical results. Compared to calc_dihedral_angle(),
this function’s API is more clear if you have the set of positions directly.
Convert a slice of any type to an array values, for use with SIMD. Padded as required. The result
will have approximately 8x fewer elements than the input.
Convert a slice of SIMD Quaternionx values, x-wide to Quaternion. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.
Convert a slice of SIMD Quaternionx values, x-wide to Quaternion. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.
Convert a slice of SIMD Vec3x values, x-wide to Vec3. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.
Convert a slice of SIMD Vec3x values, x-wide to Vec3. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.
Convert a slice of SIMD floating point values to plain floating point ones. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.
Convert a slice of SIMD floating point values to plain floating point ones. The result
will have approximately x as many elements as the input. Its parameters include
the number of original values, so it knows to only use valid lanes on the last
chunk.